==> rhdm-7.2.1-sources.zip: src/drools-wb-7.14.0.Final-redhat-00004/drools-wb-screens/drools-wb-scenario-simulation-editor/drools-wb-scenario-simulation-editor-client/src/main/java/org/drools/workbench/screens/scenariosimulation/client/popup/DeletePopupPresenter.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.workbench.screens.scenariosimulation.client.popup;

import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import org.uberfire.mvp.Command;

@Dependent
public class DeletePopupPresenter implements DeletePopup.Presenter {

    @Inject
    DeletePopupView deletePopupView;

    @Override
    public void show(final String mainTitleText,
                     final String mainQuestionText,
                     final String text1Text,
                     final String textQuestionText,
                     final String textDangerText,
                     final String okDeleteButtonText,
                     final Command okDeleteCommand) {
        deletePopupView.show(mainTitleText, mainQuestionText, text1Text, textQuestionText, textDangerText, okDeleteButtonText, okDeleteCommand);
    }

    @Override
    public void hide() {
        deletePopupView.hide();
    }
}

==> rhdm-7.3.1-sources.zip: src/drools-wb-7.18.0.Final-redhat-00004/drools-wb-screens/drools-wb-scenario-simulation-editor/drools-wb-scenario-simulation-editor-client/src/main/java/org/drools/workbench/screens/scenariosimulation/client/popup/DeletePopupPresenter.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.workbench.screens.scenariosimulation.client.popup;

import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import org.uberfire.mvp.Command;

@Dependent
public class DeletePopupPresenter implements DeletePopup.Presenter {

    @Inject
    protected DeletePopupView deletePopupView;

    @Override
    public void show(final String mainTitleText,
                     final String mainQuestionText,
                     final String text1Text,
                     final String textQuestionText,
                     final String textDangerText,
                     final String okDeleteButtonText,
                     final Command okDeleteCommand) {
        deletePopupView.show(mainTitleText, mainQuestionText, text1Text, textQuestionText, textDangerText, okDeleteButtonText, okDeleteCommand);
    }

    @Override
    public void hide() {
        deletePopupView.hide();
    }
}
